# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
"""vlass seci workflow

Revision ID: 5b468ad4c088
Revises: dd04b15a2b10
Create Date: 2021-08-24 09:12:26.244232

"""
import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = "5b468ad4c088"
down_revision = "dd04b15a2b10"
branch_labels = None
depends_on = None


script_content = """#!/bin/sh

export HOME=$TMPDIR

set -o errexit

./casa_envoy --seci $1 $2

"""

condor_content = """executable = vlass_seci.sh
arguments = metadata.json PPR.xml

output = seci.out
error = seci.err
log = condor.log

VLASS_DIR = {{data_location}}
SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/.matplotlib, $(SBIN_PATH)/pycapo, $(SBIN_PATH)/framework.sh, $(SBIN_PATH)/vela, $(SBIN_PATH)/casa_envoy, ./working, ./rawdata, ./products, {{profile}}.properties, ./PPR.xml, ./metadata.json
transfer_output_files = rawdata, working, products

request_memory = {{ramInGb}}
getenv = True
environment = "CAPO_PATH=."

{{#remote}}.requirements = NRAO_TRANSFER_HOST == "gibson-10g2"{{/remote}}

queue

"""


def upgrade():
    op.execute(
        """
        INSERT INTO workflows (workflow_name)
        VALUES ('vlass_seci')
        """
    )
    op.execute(
        f"""
        INSERT INTO workflow_templates (filename, content, workflow_name)
        VALUES ('vlass_seci.sh', E'{script_content}', 'vlass_seci')
        """
    )
    op.execute(
        f"""
        INSERT INTO workflow_templates (filename, content, workflow_name)
        VALUES ('vlass_seci.condor', E'{condor_content}', 'vlass_seci')
        """
    )


def downgrade():
    op.execute(
        """
        DELETE FROM workflows WHERE workflow_name='vlass_seci'
        """
    )
    op.execute(
        """
        DELETE FROM workflow_templates WHERE workflow_name='vlass_seci'
        """
    )
